@@ -26,7 +26,7 @@
 namespace Analitza
 {
 
-class AbstractExpressionVisitor;
+class ExpressionWriter;
 
 /**
  *	\internal
@@ -48,8 +48,6 @@ public:
 		apply,		/**< Describes an object as an application. */
 		oper,		/**< Describes an object as an operator. */
 		container,	/**< Describes an object as a container. */
-		matrix,		/**< Describes an object as a matrix. */
-		matrixrow,	/**< Describes an object as a matrix row. */
 		custom		/**< Describes a custom object */
 	};
 	
@@ -69,7 +67,7 @@ public:
 	QString toString() const;
 	
 	/** Returns some string depending on the visior */
-	virtual QVariant accept(AbstractExpressionVisitor* exp) const = 0;
+	virtual QString visit(ExpressionWriter* exp) const =0;
 	
 	virtual bool isZero() const { return false; }
 	
